@@ -1,8 +1,7 @@
 
 #' @importFrom parallel clusterExport parLapplyLB makeCluster clusterEvalQ clusterSetRNGStream
-run_parallel <- function(arg, fun, cpu = 1, simplify = "count"){
-
-  if (is.numeric(cpu)){
+run_parallel <- function(arg, fun, cpu = 1, simplify = "count") {
+  if (is.numeric(cpu)) {
     ncpu <- cpu
     stop_cl <- TRUE
     cpu <- makeCluster(cpu)
@@ -12,22 +11,22 @@ run_parallel <- function(arg, fun, cpu = 1, simplify = "count"){
     stop_cl <- FALSE
     clusterEvalQ(cpu, library("multinomineq"))
   }
-  arg <- arg[!sapply(arg, is.null)]  # omit missing arguments
+  arg <- arg[!sapply(arg, is.null)] # omit missing arguments
   arg$cpu <- 1
   clusterExport(cpu, names(arg), envir = as.environment(arg))
-  out <- parLapplyLB(cpu, seq(ncpu),
-                     function(i, arg) do.call(fun, arg), arg)
+  out <- parLapplyLB(
+    cpu, seq(ncpu),
+    function(i, arg) do.call(fun, arg), arg
+  )
   if (stop_cl) stopCluster(cpu)
 
-  if (is.null(simplify)){
+  if (is.null(simplify)) {
     return(out)
-
-  } else if (simplify == "count"){
+  } else if (simplify == "count") {
     count <- do.call("++", out)
-    count[,"steps"] <- out[[1]][,"steps"]
+    count[, "steps"] <- out[[1]][, "steps"]
     return(count)
-
-  } else if (simplify == "as.mcmc.list"){
+  } else if (simplify == "as.mcmc.list") {
     return(as.mcmc.list(out))
   } else {
     do.call(simplify, out)
@@ -35,11 +34,11 @@ run_parallel <- function(arg, fun, cpu = 1, simplify = "count"){
 }
 
 
-"++" <- function(...){
-  if ((n <- nargs()) == 1){
+"++" <- function(...) {
+  if ((n <- nargs()) == 1) {
     ..1
   } else {
     l <- list(...)
-    do.call("++",l[-n]) + l[[n]]
+    do.call("++", l[-n]) + l[[n]]
   }
 }
